==> koyomi-0.3.5.tgz: package/docs/instance.md <==
# インスタンスの作成

インスタンスを作成することで、個別に設定を持つ暦を作成することができます  
インスタンスメソッドを利用することができます  
営業日計算・カレンダーデータの作成などではインスタンスを作成しなければいけません

作成方法

```
var koyomi = new Koyomi();
```

後述するプロパティを設定時に指定することもできます

```
var koyomi = new Koyomi({
  defaultFormat: 'Y年M月D日 Ajh時m分',
  holidayOpened: true,
  regularHoliday: '木',
  seasonHoliday: '12/30-1/3, 8/16-8-18',
  startMonth: 4,
  startWeek: '日',
  six: true
});
```

以後、他のドキュメントを含め小文字で`koyomi`と記述された場合はインスタンスメソッドの呼び出し、
大文字で`Koyomi`と記述された場合はクラスメソッドが呼び出されているとします

## プロパティ

インスタンスには次のプロパティと既定値が設定されています

### フォーマット

フォーマットの既定値は`'Y-MM-DD HH:mm:ss'`です  
この値を変更した場合は、`format`メソッドで第二引数を指定しなかった場合に既定値が使用されます  
設定するには次のようにします

```
koyomi.defaultFormat = 'Y年M月D日 H時m分s秒';
```

フォーマットの書式に関しては[フォーマット ./format.md](./format.md)を参照してください

### 定休日

定休日は週や月で決められた休業日のことです  
既定値は`'土,日'`です  
複数指定するときには、カンマ区切りで指定します  
`'sun'`や`'Sunday'`なども設定することができます  
固定の日を指定する場合は、`'5,15,25'`のように数字を指定します  
第2・3水曜日などの指定は`'2水,3水'`と、何週目のあとに曜日を指定します  
5以上を指定すると最終週の指定とみなします  
これらは、混合させることもできます  
上記では対応できない場合は、関数を指定することで細かな定休日を指定することができます  
引数はDateオブジェクトのみで、定休日の場合はtrueを返すようにします

```
koyomi.regularHoliday = '日,2土,3土,30';
```

### 年末年始、お盆の休業日

定休日とは別に、年末年始・お盆の休業日を設定することができます  
こちらは日付もしくは日付の期間を設定します  
既定値は、`'12/29-1/3'`です  
お盆の期間も指定する場合は、カンマ区切りで、`'12/29-1/3, 8/16-8/18'`のように指定します  
単発の日付を指定する場合は、`'6/23, 10/10'`などとします  
上記では対応できない場合は、関数を指定することで細かな休業日を指定することができます  
引数はDateオブジェクトのみで、休業日の場合はtrueを返すようにします

```
koyomi.seasonHoliday = '12/29-1/3, 8/16-8/18';
```

### 祝日の営業

祝日を営業日にするかどうかを設定することができます  
既定値は`false`(祝日は休業日)です

```
koyomi.holidayOpened = true; // 営業日にする
```

### 年の始まり

一年の始まりを設定することができます  
既定値は`1`(1月)です  
年度の範囲を設定する重要なプロパティで様々なメソッドに影響します
標準的な会計年度にあわせ4月に設定する場合は次のようにします  

```
koyomi.startMonth = 4;
```

### 週の始まり

週の始まりを設定することができます  
既定値は`'月'`です  
カレンダーデータの作成などで使用します  
日曜日へ変更する場合は、次のようにします

```
koyomi.startWeek = '日';
```

### カレンダー取得週

 カレンダーデータを取得する際に6週分のデータを取得する際にtrueにします

 ```
 koyomi.six = true;
 ```

 # ドキュメント一覧

  + [イントロダクション ../README.md](../README.md)
  + インスタンスの作成 ./instance.md
  + [フォーマット ./format.md](./format.md)
  + [日時の情報取得・操作 ./calc-date.md](./calc-date.md)
  + [営業日計算 ./eigyobi.md](./eigyobi.md)
  + [カレンダー情報 ./calendar.md](./calendar.md)
  + [年度 ./nendo.md](./nendo.md)
  + [祝日 ./holiday.md](./holiday.md)
  + [営業・休業 ./open-close.md](./open-close.md)
  + [補助関数 ./helper.md](./helper.md)

==> koyomi-0.3.8.tgz: package/docs/instance.md <==
# インスタンスの作成

インスタンスを作成することで、個別に設定を持つ暦を作成することができます  
インスタンスメソッドを利用することができます  
営業日計算・カレンダーデータの作成などではインスタンスを作成しなければいけません

## 作成方法

```
var koyomi = new Koyomi();
```

後述するプロパティを設定時に指定することもできます

```
var koyomi = new Koyomi({
  defaultFormat: 'Y年M月D日 Ajh時m分',
  holidayOpened: true,
  regularHoliday: '木',
  seasonHoliday: '12/30-1/3, 8/16-8-18',
  startMonth: 4,
  startWeek: '日',
  six: true
});
```

以後、他のドキュメントを含め小文字で`koyomi`と記述された場合はインスタンスメソッドの呼び出し、
大文字で`Koyomi`と記述された場合はクラスメソッドが呼び出されているとします

## プロパティ

インスタンスには次のプロパティと既定値が設定されています。
既定値はクラスメソッドを使用する場合の暗黙の設定でもあり、これを変更するためには
`lib/config.js`を直接変更する必要があります。  
以後、ドキュメント内で`lib/config.js`の設定値を参照する場合は`CONFIG.FORMAT`のように記述します。

### フォーマット

フォーマットの既定値は`'YYYY-MM-DD HH:mm:ss'`です  
この値を変更した場合は、`format`メソッドで第二引数を指定しなかった場合に既定値が使用されます  
設定するには次のようにします

```
koyomi.defaultFormat = 'Y年M月D日 H時m分s秒';
```

フォーマットの書式に関しては[フォーマット ./format.md](./format.md)を参照してください

### 定休日

定休日は週や月で決められた休業日のことです  
既定値は`'土,日'`です  
複数指定するときには、カンマ区切りで指定します  
`'sun'`や`'Sunday'`なども設定することができます  
固定の日を指定する場合は、`'5,15,25'`のように数字を指定します  
第2・3水曜日などの指定は`'2水,3水'`と、何週目のあとに曜日を指定します  
5以上を指定すると最終週の指定とみなします  
これらは、混合させることもできます  
上記では対応できない場合は、関数を指定することで細かな定休日を指定することができます  
引数はDateオブジェクトのみで、定休日の場合はtrueを返すようにします

```
koyomi.regularHoliday = '日,2土,3土,30';
```

### 年末年始、お盆の休業日

定休日とは別に、年末年始・お盆の休業日を設定することができます  
こちらは日付もしくは日付の期間を設定します  
既定値は、`'12/29-1/3'`です  
お盆の期間も指定する場合は、カンマ区切りで、`'12/29-1/3, 8/16-8/18'`のように指定します  
単発の日付を指定する場合は、`'6/23, 10/10'`などとします  
上記では対応できない場合は、関数を指定することで細かな休業日を指定することができます  
引数はDateオブジェクトのみで、休業日の場合はtrueを返すようにします

```
koyomi.seasonHoliday = '12/29-1/3, 8/16-8/18';
```

### 祝日の営業

祝日を営業日にするかどうかを設定することができます  
既定値は`false`(祝日は休業日)です

```
koyomi.holidayOpened = true; // 営業日にする
```

### 年の始まり

一年の始まりを設定することができます  
既定値は`1`(1月)です  
年度の範囲を設定する重要なプロパティで様々なメソッドに影響します
標準的な会計年度にあわせ4月に設定する場合は次のようにします  

```
koyomi.startMonth = 4;
```

### 週の始まり

週の始まりを設定することができます  
既定値は`'月'`です  
カレンダーデータの作成などで使用します  
日曜日へ変更する場合は、次のようにします

```
koyomi.startWeek = '日';
```

### カレンダー取得週

 カレンダーデータを取得する際に6週分のデータを取得する際にtrueにします

 ```
 koyomi.six = true;
 ```

# ドキュメント一覧

  + [イントロダクション ../README.md](../README.md)
  + インスタンスの作成 ./instance.md
  + [フォーマット ./format.md](./format.md)
  + [日時の情報取得・操作 ./calc-date.md](./calc-date.md)
  + [営業日計算 ./eigyobi.md](./eigyobi.md)
  + [カレンダー情報 ./calendar.md](./calendar.md)
  + [年度 ./nendo.md](./nendo.md)
  + [祝日 ./holiday.md](./holiday.md)
  + [営業・休業 ./open-close.md](./open-close.md)
  + [補助関数 ./helper.md](./helper.md)
